from flask import Blueprint, Response, current_app

import inventory_provider.storage.external_inventory as external_inventory
from inventory_provider import opsdb
from inventory_provider import router_details

routes = Blueprint("inventory-data-job-routes", __name__)


@routes.route("/update", methods=['GET', 'POST'])
def update():
    router_details.update_network_details(
        current_app.config["INVENTORY_PROVIDER_CONFIG"])
    return Response("OK")


@routes.route("update-services", methods=['GET'])
def update_service():
    config = current_app.config['INVENTORY_PROVIDER_CONFIG']

    with opsdb.connection(config['ops-db']) as db:
        result = opsdb.get_circuits(db)
    external_inventory.update_services_to_monitor(result)
    return Response("OK")


@routes.route("update-interfaces", methods=['GET'])
def update_interfaces():
    config = current_app.config['INVENTORY_PROVIDER_CONFIG']

    with opsdb.connection(config['ops-db']) as db:
        result = opsdb.get_circuits(db)
    external_inventory.update_interfaces_to_services(result)
    return Response("OK")


@routes.route("update-equipment-locations", methods=['GET'])
def update_equipment_locations():
    config = current_app.config['INVENTORY_PROVIDER_CONFIG']

    with opsdb.connection(config['ops-db']) as db:
        result = opsdb.get_equipment_location_data(db)
    external_inventory.update_equipment_locations(result)
    return Response("OK")


@routes.route("update-from-inventory-system", methods=['GET'])
def update_from_inventory_system():
    config = current_app.config['INVENTORY_PROVIDER_CONFIG']

    with opsdb.connection(config['ops-db']) as db:
        result = opsdb.get_circuits(db)
    external_inventory.update_services_to_monitor(result)
    external_inventory.update_interfaces_to_services(result)
    #  todo - add other updates
    return Response("OK")


@routes.route("update-service-hierarchy", methods=['GET'])
def update_service_hierarchy():
    config = current_app.config['INVENTORY_PROVIDER_CONFIG']

    with opsdb.connection(config['ops-db']) as db:
        result = opsdb.get_circuit_hierarchy(db)
    external_inventory.update_service_hierarchy(result)
    return Response("OK")
