import json
from inventory_provider import db


services_key = "inv_services"
interfaces_key = "inv_interfaces"
equipment_locations_key = "inv_eq_locations"
service_child_to_parents_key = "inv_service_child_to_parents"
service_parent_to_children_key = "inv_service_parent_to_children"


def update_services_to_monitor(services):
    r = db.get_redis()
    relevant_types = ('path', 'service', 'l2circuit')
    for service in services:
        if service['circuit_type'].lower() in relevant_types:
            r.hset(services_key, service['id'], json.dumps(service))


def update_interfaces_to_services(services):
    r = db.get_redis()
    mapped_interfaces = {}
    for service in services:
        key = "{}::{}".format(
            service['equipment'],
            service['interface_name']
        )
        r.hset(interfaces_key, key, json.dumps(mapped_interfaces[key]))


def update_service_hierarchy(records):
    r = db.get_redis()
    children_to_parents = {}
    parents_to_children = {}
    for relation in records:
        parent_id = relation["parent_circuit_id"]
        child_id = relation["child_circuit_id"]
        if child_id not in children_to_parents:
            children_to_parents[child_id] = []
        if parent_id not in parents_to_children:
            parents_to_children[parent_id] = []

        parents_to_children[parent_id].append(relation)
        children_to_parents[child_id].append(relation)
    for child, parents in children_to_parents.items():
        r.hset(service_child_to_parents_key, child, json.dumps(parents))
    for parent, children in parents_to_children.items():
        r.hset(service_parent_to_children_key, parent, json.dumps(children))


def update_equipment_locations(equipment_location_data):
    r = db.get_redis()
    for ld in equipment_location_data:
        r.hset(equipment_locations_key, ld['equipment_name'], json.dumps(ld))
